@@ -48,7 +48,7 @@ class Connection(Session):
         filters: dict = None,
         tags: dict = None,
         share_url: int = 0,
-        country_codes: str = None,
+        country_codes: List[str] = None,
         exact_match: bool = False,
     ) -> dict:
         """
